package com.ningdatech.pmapi.user.controller;


import com.ningdatech.basic.model.PageVo;
import com.ningdatech.pmapi.user.manage.UserInfoManage;
import com.ningdatech.pmapi.user.model.po.ReqUserDetailEditPO;
import com.ningdatech.pmapi.user.model.po.ReqUserDisablePO;
import com.ningdatech.pmapi.user.model.po.ReqUserInfoListPO;
import com.ningdatech.pmapi.user.model.vo.ResUserDetailVO;
import com.ningdatech.pmapi.user.model.vo.ResUserInfoListVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;

import javax.validation.Valid;

/**
 * <p>
 * 用户信息表 前端控制器
 * </p>
 *
 * @author Liuxinxin
 * @since 2023-01-04
 */
@Controller
@RequestMapping("/api/v1/user-info")
@RequiredArgsConstructor
@Api(value = "UserInfoController", tags = "用户管理")
public class UserInfoController {

    private final UserInfoManage userInfoManage;

    @ApiOperation(value = "用户列表搜索", notes = "用户列表搜索")
    @PostMapping("/list")
    public PageVo<ResUserInfoListVO> userInfoList(@Valid @RequestBody ReqUserInfoListPO reqUserInfoListPO) {
        return userInfoManage.list(reqUserInfoListPO);
    }

    @ApiOperation(value = "用户禁用", notes = "用户禁用")
    @PostMapping("/disable")
    public void disable(@Valid @RequestBody ReqUserDisablePO reqUserDisablePO) {
        userInfoManage.disable(reqUserDisablePO);
    }

    @ApiOperation(value = "用户详情", notes = "用户详情")
    @PostMapping("/detail")
    public ResUserDetailVO userInfoDetail(@Valid @RequestBody ReqUserInfoListPO reqUserInfoListPO) {
        return userInfoManage.userInfoDetail(reqUserInfoListPO);
    }

    @ApiOperation(value = "用户详情编辑", notes = "用户详情编辑")
    @PostMapping("/detail/edit")
    public void userInfoDetailEdit(@Valid @RequestBody ReqUserDetailEditPO reqUserDetailEditPO) {
        userInfoManage.userInfoDetailEdit(reqUserDetailEditPO);
    }


}
